@@ -164,7 +164,10 @@ const int COPYDATA_FULL_CMDLINE = 3;
 
 #define NPP_STYLING_FILESIZE_LIMIT_DEFAULT (200 * 1024 * 1024) // 200MB+ file won't be styled
 
+#define FINDREPLACE_MAXLENGTH 16384      // the maximum length of the string (decrease 1 for '\0') to search in the editor
+
 const int FINDREPLACE_INSELECTION_THRESHOLD_DEFAULT = 1024;
+const int FILL_FINDWHAT_THRESHOLD_DEFAULT = 1024;
 
 const wchar_t fontSizeStrs[][3] = {L"", L"5", L"6", L"7", L"8", L"9", L"10", L"11", L"12", L"14", L"16", L"18", L"20", L"22", L"24", L"26", L"28"};
 
@@ -266,11 +269,14 @@ struct CmdLineParams
 {
 	bool _isNoPlugin = false;
 	bool _isReadOnly = false;
+	bool _isFullReadOnly = false;
+	bool _isFullReadOnlySavingForbidden = false;
 	bool _isNoSession = false;
 	bool _isNoTab = false;
 	bool _isPreLaunch = false;
 	bool _showLoadingTime = false;
 	bool _alwaysOnTop = false;
+	bool _displayCmdLineArgs = false;
 	intptr_t _line2go   = -1;
 	intptr_t _column2go = -1;
 	intptr_t _pos2go = -1;
@@ -305,7 +311,8 @@ struct CmdLineParams
 	}
 };
 
-// A POD class to send CmdLineParams through WM_COPYDATA and to Notepad_plus::loadCommandlineParams
+// Command Line Parameters Data Transfer Object class:
+// A POD (Plain Old Data) class to send CmdLineParams through WM_COPYDATA and to Notepad_plus::loadCommandlineParams
 struct CmdLineParamsDTO
 {
 	bool _isReadOnly = false;
@@ -321,7 +328,7 @@ struct CmdLineParamsDTO
 
 	LangType _langType = L_EXTERNAL;
 	wchar_t _udlName[MAX_PATH] = {'\0'};
-	wchar_t _pluginMessage[MAX_PATH] = {'\0'};
+	wchar_t _pluginMessage[2048] = {'\0'};
 
 	static CmdLineParamsDTO FromCmdLineParams(const CmdLineParams& params)
 	{
@@ -339,7 +346,7 @@ struct CmdLineParamsDTO
 
 		dto._langType = params._langType;
 		wcsncpy(dto._udlName, params._udlName.c_str(), MAX_PATH);
-		wcsncpy(dto._pluginMessage, params._pluginMessage.c_str(), MAX_PATH);
+		wcsncpy(dto._pluginMessage, params._pluginMessage.c_str(), 2048);
 		return dto;
 	}
 };
@@ -875,6 +882,8 @@ struct NppGUI final
 	bool _rememberLastSession = true; // remember next session boolean will be written in the settings
 	bool _keepSessionAbsentFileEntries = false;
 	bool _isCmdlineNosessionActivated = false; // used for if -nosession is indicated on the launch time
+	bool _isFullReadOnly = false;
+	bool _isFullReadOnlySavingForbidden = false;
 	bool _detectEncoding = true;
 	bool _saveAllConfirm = true;
 	bool _setSaveDlgExtFiltToAllTypes = false;
@@ -906,6 +915,7 @@ struct NppGUI final
 	bool _confirmReplaceInAllOpenDocs = true;
 	bool _replaceStopsWithoutFindingNext = false;
 	int _inSelectionAutocheckThreshold = FINDREPLACE_INSELECTION_THRESHOLD_DEFAULT;
+	int _fillFindWhatThreshold = FILL_FINDWHAT_THRESHOLD_DEFAULT;
 	bool _fillDirFieldFromActiveDoc = false;
 	bool _muteSounds = false;
 	bool _enableFoldCmdToggable = false;
@@ -1320,7 +1330,7 @@ struct ColumnEditorParam final
 	int _initialNum = -1;
 	int _increaseNum = -1;
 	int _repeatNum = -1;
-	int _formatChoice = 0; // 0:Dec 1:Hex 2:Oct 3:Bin
+	int _formatChoice = 0; // 0:Dec 1:Hex 2:Oct 3:Bin 4:HexUpperCase
 	leadingChoice _leadingChoice = noneLeading;
 };
 
