@@ -20,6 +20,7 @@
 #include "dockingResource.h"
 #include "Docking.h"
 
+#include <array>
 #include <assert.h>
 #include <shlwapi.h>
 #include "Common.h"
@@ -41,7 +42,7 @@ public:
 		_moduleName = ::PathFindFileName(temp);
 	}
 
-	void create(tTbData* data, bool isRTL = false) {
+	virtual void create(tTbData* data, bool isRTL = false) {
 		assert(data != nullptr);
 		StaticDialog::create(_dlgID, isRTL);
 		wchar_t temp[MAX_PATH];
@@ -56,7 +57,12 @@ public:
 		data->uMask = 0;
 
 		// additional info
-		data->pszAddInfo = NULL;
+		data->pszAddInfo = nullptr;
+	}
+
+	virtual void create(tTbData* data, std::array<int, 3> iconIDs, bool isRTL = false) {
+		create(data, isRTL);
+		_iconIDs = iconIDs;
 	}
 
 	virtual void updateDockingDlg() {
@@ -82,12 +88,17 @@ public:
 		return _moduleName.c_str();
 	}
 
+	const std::array<int, 3>& getIconIDs() const {
+		return _iconIDs;
+	}
+
 protected :
 	int	_dlgID = -1;
-	bool _isFloating = true;
 	int _iDockedPos = 0;
 	std::wstring _moduleName;
 	std::wstring _pluginName;
+	std::array<int, 3> _iconIDs{};
+	bool _isFloating = true;
 	bool _isClosed = false;
 
 	intptr_t CALLBACK run_dlgProc(UINT message, WPARAM wParam, LPARAM lParam) override {
@@ -100,14 +111,14 @@ protected :
 					break;
 				}
 
-				RECT rc = {};
+				RECT rc{};
 				getClientRect(rc);
 				::FillRect(reinterpret_cast<HDC>(wParam), &rc, NppDarkMode::getDlgBackgroundBrush());
 				return TRUE;
 			}
-			case WM_NOTIFY: 
+			case WM_NOTIFY:
 			{
-				LPNMHDR	pnmh = reinterpret_cast<LPNMHDR>(lParam);
+				auto* pnmh = reinterpret_cast<LPNMHDR>(lParam);
 
 				if (pnmh->hwndFrom == _hParent)
 				{
