@@ -1039,7 +1039,7 @@ void CustomFileDialog::setSaveAsCopy(bool isSavingAsCopy)
 	}
 }
 
-bool CustomFileDialog::getOpenTheCopyAfterSaveAsCopy(void)
+bool CustomFileDialog::getOpenTheCopyAfterSaveAsCopy()
 {
 	return (_impl->_savingAsCopyInfo & SAVE_AS_COPY_OPEN) != 0;
 }
@@ -1077,7 +1077,7 @@ wstring CustomFileDialog::doSaveDlg()
 
 	CurrentDirBackup backup;
 
-	_impl->addFlags(FOS_PATHMUSTEXIST | FOS_FILEMUSTEXIST | FOS_FORCEFILESYSTEM);
+	_impl->addFlags(FOS_PATHMUSTEXIST | FOS_FILEMUSTEXIST | FOS_FORCEFILESYSTEM | FOS_NOTESTFILECREATE);
 	bool bOk = _impl->show();
 	return bOk ? _impl->getResultFilename() : L"";
 }
