@@ -481,12 +481,15 @@ void TabBarPlus::tabToStart(int index)
 
 	if (index <= 0)
 		return;
-
-	for (int i = index, j = index - 1; j >= 0; --i, --j)
+	int i = index, j = index - 1;
+	for (; j >= 0; --i, --j)
 	{
-		if (!exchangeTabItemData(i, j))
+		if (!exchangeTabItemData(i, j, false))
+		{
 			break;
+		}
 	}
+	setActiveTab(i);
 }
 
 void TabBarPlus::tabToEnd(int index)
@@ -496,12 +499,13 @@ void TabBarPlus::tabToEnd(int index)
 
 	if (index >= static_cast<int>(_nbItem))
 		return;
-
-	for (int i = index, j = index + 1; j < static_cast<int>(_nbItem); ++i, ++j)
+	int i = index, j = index + 1;
+	for (; j < static_cast<int>(_nbItem); ++i, ++j)
 	{
-		if (!exchangeTabItemData(i, j))
+		if (!exchangeTabItemData(i, j, false))
 			break;
 	}
+	setActiveTab(i);
 }
 
 void TabBarPlus::setCloseBtnImageList()
@@ -1175,14 +1179,35 @@ LRESULT TabBarPlus::runProc(HWND hwnd, UINT Message, WPARAM wParam, LPARAM lPara
 
 		case WM_LBUTTONDBLCLK:
 		{
-			bool isDbClk2Close = NppParameters::getInstance().getNppGUI()._tabStatus & TAB_DBCLK2CLOSE;
-			if (isDbClk2Close)
+			NppParameters& nppParam = NppParameters::getInstance();
+			NppGUI& nppGUI = nppParam.getNppGUI();
+
+			bool isVertical = nppGUI._tabStatus & TAB_VERTICAL;
+			bool isDbClk2Close = nppGUI._tabStatus & TAB_DBCLK2CLOSE;
+
+			int xPos = LOWORD(lParam);
+			int yPos = HIWORD(lParam);
+			int currentTabOn = getTabIndexAt(xPos, yPos);
+
+			if (currentTabOn != -1)
 			{
-				int xPos = LOWORD(lParam);
-				int yPos = HIWORD(lParam);
-				int currentTabOn = getTabIndexAt(xPos, yPos);
-				notify(TCN_TABDELETE, currentTabOn);
+				if (isDbClk2Close)
+					notify(TCN_TABDELETE, currentTabOn);
 			}
+			else
+			{
+				POINT pt{};
+				GetCursorPos(&pt);
+
+				RECT rcLastTab{};
+				TabCtrl_GetItemRect(_hSelf, static_cast<int32_t>(TabCtrl_GetItemCount(_hSelf)) - 1, &rcLastTab);
+				ClientRectToScreenRect(_hSelf, &rcLastTab);
+
+				bool isDbClickOnTabStrip = isVertical ? (pt.x < rcLastTab.right) : (pt.y < rcLastTab.bottom);
+				if (isDbClickOnTabStrip)
+					::SendMessage(_hParent, WM_COMMAND, IDM_FILE_NEW, 0);
+			}
+
 			return TRUE;
 		}
 
@@ -1392,9 +1417,9 @@ void TabBarPlus::drawItem(DRAWITEMSTRUCT* pDrawItemStruct, bool isDarkMode)
 	const COLORREF colorActiveBg = isDarkMode ? NppDarkMode::getCtrlBackgroundColor() : ::GetSysColor(COLOR_BTNFACE);
 	const COLORREF colorInactiveBgBase = isDarkMode ? NppDarkMode::getBackgroundColor() : ::GetSysColor(COLOR_BTNFACE);
 	
-	COLORREF colorInactiveBg = liteGrey;
-	COLORREF colorActiveText = ::GetSysColor(COLOR_BTNTEXT);
-	COLORREF colorInactiveText = grey;
+	COLORREF colorInactiveBg = _inactiveBgColour;
+	COLORREF colorActiveText = _activeTextColour;
+	COLORREF colorInactiveText = _inactiveTextColour;
 
 	if (!NppDarkMode::useTabTheme() && isDarkMode)
 	{
@@ -1402,12 +1427,6 @@ void TabBarPlus::drawItem(DRAWITEMSTRUCT* pDrawItemStruct, bool isDarkMode)
 		colorActiveText = NppDarkMode::getTextColor();
 		colorInactiveText = NppDarkMode::getDarkerTextColor();
 	}
-	else
-	{
-		colorInactiveBg = _inactiveBgColour;
-		colorActiveText = _activeTextColour;
-		colorInactiveText = _inactiveTextColour;
-	}
 
 	HDC hDC = pDrawItemStruct->hDC;
 
@@ -1814,7 +1833,7 @@ void TabBarPlus::setActiveTab(int tabIndex)
 	notify(TCN_SELCHANGE, tabIndex);
 }
 
-bool TabBarPlus::exchangeTabItemData(int oldTab, int newTab)
+bool TabBarPlus::exchangeTabItemData(int oldTab, int newTab, bool setToActive/* = true */)
 {
 	//1. shift their data, and insert the source
 	TCITEM itemData_nDraggedTab{}, itemData_shift{};
@@ -1862,7 +1881,8 @@ bool TabBarPlus::exchangeTabItemData(int oldTab, int newTab)
 	::SendMessage(_hParent, NPPM_INTERNAL_DOCORDERCHANGED, 0, oldTab);
 
 	//2. set to focus
-	setActiveTab(newTab);
+	if (setToActive)
+		setActiveTab(newTab);
 
 	return true;
 }
