@@ -184,6 +184,8 @@
     #define    IDM_EDIT_MULTISELECTSSKIP                        (IDM_EDIT + 99)
     #define    IDM_EDIT_SORTLINES_LOCALE_ASCENDING              (IDM_EDIT + 100)
     #define    IDM_EDIT_SORTLINES_LOCALE_DESCENDING             (IDM_EDIT + 101)
+    #define    IDM_EDIT_SETREADONLYFORALLDOCS                   (IDM_EDIT + 102)
+    #define    IDM_EDIT_CLEARREADONLYFORALLDOCS                 (IDM_EDIT + 103)
 
     #define    IDM_EDIT_AUTOCOMPLETE                            (50000 + 0)
     #define    IDM_EDIT_AUTOCOMPLETE_CURRENTFILE                (50000 + 1)
@@ -594,10 +596,10 @@
 
 
 #define    IDM_SETTING    (IDM + 8000)
-//    #define    IDM_SETTING_TAB_SIZE                 (IDM_SETTING + 1)
-//    #define    IDM_SETTING_TAB_REPLACESPACE         (IDM_SETTING + 2)
-//    #define    IDM_SETTING_HISTORY_SIZE             (IDM_SETTING + 3)
-//    #define    IDM_SETTING_EDGE_SIZE                (IDM_SETTING + 4)
+//  #define    IDM_SETTING_TAB_SIZE                 (IDM_SETTING + 1)
+//  #define    IDM_SETTING_TAB_REPLACESPACE         (IDM_SETTING + 2)
+//  #define    IDM_SETTING_HISTORY_SIZE             (IDM_SETTING + 3)
+//  #define    IDM_SETTING_EDGE_SIZE                (IDM_SETTING + 4)
     #define    IDM_SETTING_IMPORTPLUGIN             (IDM_SETTING + 5)
     #define    IDM_SETTING_IMPORTSTYLETHEMES        (IDM_SETTING + 6)
     #define    IDM_SETTING_TRAYICON                 (IDM_SETTING + 8)
@@ -643,6 +645,8 @@
     #define  IDM_WINDOW_SORT_FT_DSC	(IDR_WINDOWS_MENU + 7)
     #define  IDM_WINDOW_SORT_FS_ASC	(IDR_WINDOWS_MENU + 8)
     #define  IDM_WINDOW_SORT_FS_DSC	(IDR_WINDOWS_MENU + 9)
+    #define  IDM_WINDOW_SORT_FD_ASC	(IDR_WINDOWS_MENU + 10)
+    #define  IDM_WINDOW_SORT_FD_DSC	(IDR_WINDOWS_MENU + 11)
     #define  IDM_WINDOW_MRU_FIRST 	(IDR_WINDOWS_MENU + 20)
     #define  IDM_WINDOW_MRU_LIMIT 	(IDR_WINDOWS_MENU + 59)
     #define  IDM_WINDOW_COPY_NAME 	(IDM_WINDOW_MRU_LIMIT + 1)
